local addonName = ...
local guildName = nil
local db = nil

local today = nil
local sessionTotal = 0

local function updateTooltip(tt)
	tt:AddLine("Guild Money")
	if sessionTotal > 0 then
		tt:AddDoubleLine("This session", GetCoinText(sessionTotal, "/"), 1, 1, 1, 0, 1, 0)
	end
	if db[today] and db[today] > 0 then
		tt:AddDoubleLine(HONOR_TODAY, GetCoinText(db[today] or 0, "/"), 1, 1, 1, 0, 1, 0)
	end
	local week = 0
	for i = today, (today - 7), -1 do
		week = week + (db[i] or 0)
	end
	if week > 0 then
		tt:AddDoubleLine(CALENDAR_REPEAT_WEEKLY, GetCoinText(week, "/"), 1, 1, 1, 0, 1, 0)
	end
	local month = week
	for i = (today - 7), (today - 30), -1 do
		month = month + (db[i] or 0)
	end
	if month > 0 then
		tt:AddDoubleLine(CALENDAR_REPEAT_MONTHLY, GetCoinText(month, "/"), 1, 1, 1, 0, 1, 0)
	end
end

local ldb = LibStub("LibDataBroker-1.1")
local bGuildMoney = ldb:NewDataObject("Reagents", {
	type = "data source",
	icon = "Interface\\MoneyFrame\\UI-GoldIcon",
	text = "Guild money",
	OnTooltipShow = updateTooltip,
})

local matchGold = GOLD_AMOUNT:gsub("%%d", "(%%d+)")
local matchSilver = SILVER_AMOUNT:gsub("%%d", "(%%d+)")
local matchCopper = COPPER_AMOUNT:gsub("%%d", "(%%d+)")
local personalMoney = YOU_LOOT_MONEY:gsub("%%s", "(.+)")
local guildMoney = YOU_LOOT_MONEY_GUILD:gsub("%(", "%%("):gsub("%)", "%%)"):gsub("%%s", "(.+)")

local function getTotalFromString(msg)
	local g = msg:match(matchGold) or 0 * 1000
	local s = msg:match(matchSilver) or 0 * 100
	local c = msg:match(matchCopper) or 0
	return g + s + c
end

local f = CreateFrame("Frame")
f:RegisterEvent("ADDON_LOADED")
f:SetScript("OnEvent", function(self, event, addon)
	if addon ~= addonName then return end
	guildName = GetGuildInfo("player")
	if not guildName then
		print("startup failed.")
		return
	end
	BGMDB = BGMDB or {}
	if not BGMDB[guildName] then BGMDB[guildName] = {} end
	db = BGMDB[guildName]

	-- Borrowed from MoneyFu (probably ckk)
	local serverHour, serverMinute = GetGameTime()
	local utcHour = tonumber(date("!%H"))
	local utcMinute = tonumber(date("!%M"))
	local ser = serverHour + serverMinute / 60
	local utc = utcHour + utcMinute / 60
	local offset = floor((ser - utc) * 2 + 0.5) / 2
	if offset >= 12 then
		offset = offset - 24
	elseif offset < -12 then
		offset = offset + 24
	end
	today = floor((time() / 60 / 60 + offset) / 24)
end)

local function filter(self, event, msg, ...)
	local personal, guild = msg:match(guildMoney)
	-- |not db| catches failed startup
	if not db or not guild then return end

	sessionTotal = sessionTotal + (getTotalFromString(guild) or 0)
	db[today] = (db[today] or 0) + sessionTotal

	bGuildMoney.text = GetCoinText(sessionTotal, "/")

	local t = GetCoinTextureString(getTotalFromString(personal))
	return false, YOU_LOOT_MONEY:format(t), ...
end

ChatFrame_AddMessageEventFilter("CHAT_MSG_MONEY", filter)

